===========================
tt: logical tools for logic
===========================

Welcome to the documentation site for tt!

-----

.. warning::
    tt is heavily tested and fully usable, but is still pre-1.0/stable software with **no guarantees** of avoiding breaking API changes until hitting version 1.0.


.. include:: ../README.rst


.. toctree::
    :hidden:

    user_guide
    release_notes
    development
    prior_art
    special_thanks
    author


Want to learn more?
-------------------

If you're just getting started and looking for tutorial-style documentation, head on over to the :doc:`User Guide </user_guide>`. If you would prefer a comprehensive view of this library's functionality, check out the API docs:

.. toctree::
    :maxdepth: 1
    :glob:

    api/*
